###############################################################################
# Copyright (c) 2018, Urban Magnetometry Group.
# Produced at the University of California at Berkeley.
# Written by V. Dumont (vincentdumont11@gmail.com).
# All rights reserved.
# This file is part of NURI.
# For details, see gitlab.com/citymag/analysis/nuri.
# For details about use and distribution, please read NURI/LICENSE.
###############################################################################
__version__ = '1.0.0'
from .analysis import *
from .extract import *
from .utils import *



###############################################################################
# Copyright (c) 2018, Urban Magnetometry Group.
# Produced at the University of California at Berkeley.
# Written by V. Dumont (vincentdumont11@gmail.com).
# All rights reserved.
# This file is part of NURI.
# For details, see github.com/vincentdumont/nuri.
# For details about use and distribution, please read NURI/LICENSE.
###############################################################################

# System
import os
import sys
import time
from datetime import datetime

# External
import numpy
from gwpy.timeseries import TimeSeries

def data_chunk(data,hours,samp_per_hr=3600):
    """
    Concatenate data chunks for a given time period. Given a specific
    time period, this method will loop through all available days and
    concatenate time series data that fall in the same time period.
    This function is used in `our paper <http://citymag.gitlab.io/nuri/paper#Fig.-3:-Power-Spectral-Density>`_
    when building Power Spectral Densities at low frequencies.

    Parameters
    ----------
    data : :class:`numpy.ndarray`
      Input magnetic field data.
    hours : :class:`list` [ :class:`int` ]
      Start and final hours of the daily period.
    samp_per_hr : :class:`int`
      Number of samples in an hour of data.

    Returns
    -------
    avg : :class:`list`
      List of concatenated time series values.

    Examples
    --------
    In the example below, we concatenate 2 hours of time series data,
    from 9 to 11 AM, over a 4-day period, from 1st to 5th of April 2016.
    The data are sampled at 1-Hertz, so 3,600 data points per hour.
    Therefore, a total of 3600 data points * 2 hours * 4 days = 28,800
    data points returned.

    >>> data = nuri.get_data('2016-4-1','2016-4-5','/content/drive/MyDrive/CityMagData/1Hz',station=2,sensor='biomed',scalar=True)
    >>> data = nuri.data_chunk(data.value,[9,11],samp_per_hr=3600)
    >>> print(len(data))
    28800
    """
    avg = []
    for i in range(0,len(data),samp_per_hr*24):
        imin = int(hours[0]*samp_per_hr)
        imax = int(hours[1]*samp_per_hr)
        avg.extend(data[i+imin:i+imax])
    return avg

def day_and_night(data,daytime,samp_per_hr=3600):
    """
    Split data into separate day and night time-series.

    Parameters
    ----------
    data : :class:`numpy.ndarray`
      Input magnetic field data.
    daytime : :class:`list` [ :class:`list` [ :class:`int` ] ]
      List of daytime hour ranges. Multiple ranges can be provided
      in case the night time starts after midnight.
    samp_per_hr : :class:`int`
      Number of samples in an hour of data.

    Returns
    -------
    day :  :class:`list` [ :class:`float` ]
      Concatenated daytime time-series.
    night :  :class:`list` [ :class:`float` ]
      Concatenated nighttime time-series.    

    Examples
    --------
    >>> data = nuri.get_data('2016-4-1','2016-4-3','/content/drive/MyDrive/CityMagData/1Hz',station=2,sensor='biomed',scalar=True)
    >>> day, night = nuri.day_and_night(data.value,daytime=[[0,1],[4.5,24]])
    >>> print(len(day),len(night))
    147581 25200
    """
    day, night = [], []
    for i in range(0,len(data),samp_per_hr*24):
        for n,(imin,imax) in enumerate(daytime):
            hmin = int(imin*samp_per_hr)
            hmax = int(imax*samp_per_hr)
            day.extend(data[i+hmin:i+hmax])
            if n==0:
                night.extend(data[i:i+hmin])
            if n+1<len(daytime):
                hnext = int(daytime[n+1][0]*samp_per_hr)
                night.extend(data[i+hmax:i+hnext])
            if n+1==len(daytime):
                night.extend(data[i+hmax:i+24*samp_per_hr])
    return day, night

def downsample(data,downfactor):
    """
    Downsample data time series.
    """
    times = data[:,0] if downfactor==1 else data[::downfactor,0][:-1]
    # Get closest multiple of the downsample factor from the data length
    limit = int(downfactor * round(float(len(data))/downfactor))
    # Ensure data length is multiple of downsampling factor
    data = data[:limit,1] if limit<=len(data) else data[:limit-downfactor,1]
    # Re-sample the data
    data = signal.resample(data,len(data)//downfactor)
    # Create dataset
    data = numpy.vstack((times,data)).T
    return data

def str2timestamp(*times):
    """
    Convert times into datetime timestamps.
    
    Parameters
    ----------
    times : :class:`list` [ :class:`str` ]
      Start and final times of the target period.

    Returns
    -------
    time_list : :class:`list` [ :class:`float` ]
      Dates converted into floating timestamps

    Examples
    --------
    >>> times = nuri.str2timestamp('2016-4-1','2016-4-5')
    >>> print(times)
    (1459468800.0, 1459814400.0)
    """
    time_list = []
    for dt in times:
        # Split date by dashes
        dt = numpy.array(dt.split('-'),dtype=int)
        # Include day 1 if no day provided
        dt = dt if len(dt)>2 else numpy.hstack((dt,1))
        # Convert string to datetime format
        dt = datetime(*dt)
        # Convert start date into timestamp
        dt = time.mktime(dt.timetuple())+dt.microsecond/1e6
        # Convert timestamp back local datetime
        now = datetime.fromtimestamp(dt)
        # Convert timestamp to UTC datetime
        utc_now = datetime.utcfromtimestamp(dt)
        # Calculate local difference with UTC time
        utc2local = (now-utc_now).total_seconds()
        # Remove UTC offset from timestamp
        dt += utc2local
        time_list.append(dt)
    return tuple(time_list) if len(time_list)>1 else time_list[0]

def str2datetime(*dates):
    '''
    Convert input string date to datetime format.
    '''
    date_list = []
    for date in dates:
        dstr = ['%Y','%m','%d','%H','%M','%S','%f']
        dsplit = '-'.join(dstr[:date.count('-')+1])
        date = datetime.strptime(date,dsplit)
        date_list.append(date)
    return tuple(date_list) if len(date_list)>1 else date_list[0]

def is_float(a):
    """
    Return whether input variable is a float.
    """
    try:
        float(a)
        return True
    except ValueError:
        return False

def make_video():
    """
    Make video out of saved figures.
    """
    os.system('ls *.png > list.dat')
    filelist = sorted(numpy.loadtxt('list.dat',dtype=str))
    for i in range(len(filelist)):
        newpath = 'series%04i.png'%(i+1)
        if os.path.exists(newpath)==False:
            os.system('cp %s %s'%(filelist[i],newpath))
    os.system('ffmpeg -framerate 30 -i series%04d.png  -start_number 1 -c:v libx264 -r 30 -pix_fmt yuv420p ../video.mp4')
    os.system('rm list.dat series*')
    
def fix_jumps(data,nsamp=1800,edge=5):
    '''
    Fix jumps in time series data.

    Examples
    --------
    >> import nuri
    >> berkeley = berkeley_raw[:-1].copy()
    >> berkeley = nuri.fix_jumps(berkeley,edge=10)
    >> berkeley = nuri.normalize(berkeley,saved='saved.dat',play=False).get_updated_data()
    '''
    for i in range(0,len(data)-nsamp,nsamp):
        var = numpy.var(data.value[i:i+nsamp])
        if abs(var)>0.1:
            for j in range(i+nsamp,i,-1):
                if numpy.var(data.value[j:i+nsamp])>0.005:
                    j-=edge
                    break
            for k in range(i,i+nsamp):
                if numpy.var(data.value[i:k])>0.005:
                    k+=edge
                    break
            break
    data.value[j:k] = data.value[j]
    data.value[k:] -= (data.value[k]-data.value[j])
    return data

def get_variance(data,period='weekday',bin_size=1200):
  start,length = (0,5) if period=='weekday' else (5,2)
  variances = []
  for n,i in enumerate(range(0,len(data)-3600*24,3600*24)):
    if n in numpy.array([numpy.arange(i,i+length) for i in range(start,35,7)]):
      var = []
      for j in range(i,i+3600*24,bin_size):
        var.append(numpy.var(data[j:j+bin_size]))
      variances.append(var)
  var = numpy.mean(variances,axis=0)
  times = numpy.linspace(0,24,len(var))
  return times,var

def rescale(freqs,data,num=1000,mode='linear'):
  if mode=='linear':
    new_freqs = numpy.linspace(freqs[0],freqs[-1],num)
    new_data = [data[abs(freqs-f).argmin()] for f in new_freqs]
    return numpy.array(new_freqs),numpy.array(new_data)
  if mode=='log':
    new_freqs = numpy.logspace(numpy.log10(freqs[1]),numpy.log10(freqs[-1]),num)
    new_data = [data[abs(freqs-f).argmin()] for f in new_freqs]
    return numpy.concatenate(([freqs[0]],new_freqs)),numpy.concatenate(([data[0]],new_data))

def transform_data(data_full,length,sample_rate=1,omega0=6,dj=0.05):
    import mlpy
    data   = data_full[:length]
    scales = mlpy.wavelet.autoscales(N=len(data.value),dt=1./sample_rate,dj=dj,wf='morlet',p=omega0)
    freqs  = (omega0 + numpy.sqrt(2.0 + omega0 ** 2)) / (4 * numpy.pi * scales[1:])
    spec   = mlpy.wavelet.cwt(data.value,dt=1./sample_rate,scales=scales,wf='morlet',p=omega0)
    spec   = numpy.abs(spec)**2
    return scales,freqs,spec

def normalize(data):
    data -= numpy.median(data)
    data /= max(abs(data))
    return data




#!/usr/bin/env python
import numpy,os
import matplotlib.pyplot as plt

def fft_animation():
    for i,f in enumerate(numpy.arange(1,20.02,0.02)):
        print(round(f,2))
        omega = 2.*numpy.pi*f
        time_interval = 1
        plt.figure(figsize=(15,5))
        x2 = numpy.linspace(0,time_interval,21)
        y2 = numpy.sin(x2*omega+numpy.pi/2)
        plt.plot(x2,y2,marker='o',color='black')
        x1 = numpy.linspace(0,time_interval,1000)
        y1 = numpy.sin(x1*omega+numpy.pi/2)
        plt.plot(x1,y1,lw=1,color='red')
        plt.xlim(0,1)
        plt.ylim(-1.1,1.1)
        plt.xlabel('Time [second]')
        plt.ylabel('Amplitude')
        plt.title('Signal Frequency: %.2f Hz'%f)
        plt.tight_layout()
        plt.savefig('image-%04i'%(i+1),dpi=150)
        plt.close()
    os.system('ffmpeg -r 25 -f image2 -i image-%04d.png -vcodec libx264 -crf 25  -pix_fmt yuv420p fft.mp4')
    os.system('rm image*')
    os.system('open fft.mp4')

if __name__=='__main__':
    fft_animation()



import numpy, math
from scipy.optimize import curve_fit
from scipy import special

class GaussianFit:
  """
  Fit Gaussian profile(s) to the distribution of magnetic field data.

  Examples
  --------
  >>> data = nuri.get_data('2016-3-14','2016-4-11','/content/drive/MyDrive/CityMagData/1Hz',station=2,sensor='biomed',scalar=True)
  >>> x,y,y1,y2 = nuri.gaussian_fit(mode='gauss',data=data.value,bins=45,xlim=[48.8,50.3],order=2)
  1/2 Gaussian : amp=140184.97, mu=49.55, sigma=0.212
  2/2 Gaussian : amp=38811.87, mu=49.85, sigma=0.054
  """
  def __init__(self,data,bins,xlim,order=1,reference=[]):
    """
    Initialize Gaussian fitting class. When 2 Gaussian profiles are
    being fitted, i.e., ``order`` is equal to 2, and a reference
    dataset is provide, a single Gaussian profile will first be
    fitted to the reference data; a double Gaussian profile will then
    be fitted to the entire input dataset with the parameters from the
    reference profile being fixed.

    Parameters
    ----------
    data : :class:`numpy.ndarray`
      Input magnetic field data.
    bins : :class:`int`
      Number of bins in the histogram.
    xlim : :class:`list` [ :class:`float` ]
      Range to generate histograms from the data.
    order : :class:`int`
      Number of Gaussian profiles to fit the data with.
    reference : :class:`list` [ :class:`float` ]
      Reference dataset to fit the first Gaussian profile.
    """
    self.xlim = xlim
    self.order = order
    hist = numpy.histogram(data,bins,range=xlim)
    x = numpy.array([0.5 * (hist[1][i] + hist[1][i+1]) for i in range(len(hist[1])-1)])
    y = hist[0]
    params = [max(y)/2,numpy.mean(data),numpy.std(data)]*order
    self.reference = reference
    if len(reference)>0:
      self.reference = GaussianFit(reference,bins,xlim).get_params()
      params = params[3:]
    self.gauss_fit(x,y,params)

  def gauss_single(self,x,amp,mu,sigma):
    return (amp * numpy.exp(-(x - mu)**2.0 / (2 * sigma**2)))

  def gauss_fct(self,x,*params):
    gauss = 0
    for i in range(self.order):
      if i==0 and self.reference!=[]:
        amp, mu, sigma = self.reference
      else:
        idx = i if self.reference==[] else i-1
        amp, mu, sigma = params[idx*3:idx*3+3]
      gauss += self.gauss_single(x, amp, mu, sigma)
    return gauss

  def gauss_fit(self,x,y,params):
    popt, pcov = curve_fit(self.gauss_fct,x,y,p0=params)
    print('1/%i Gaussian : amp=%.2f, mu=%.2f, sigma=%.3f'%(self.order,popt[0],popt[1],abs(popt[2])))
    if self.order>1 and self.reference==[]:
      print('2/%i Gaussian : amp=%.2f, mu=%.2f, sigma=%.3f'%(self.order,popt[3],popt[4],abs(popt[5])))
    self.popt = self.reference+list(popt)

  def get_params(self):
    return self.popt

  def get_fit(self):
    self.reference = []
    x = numpy.arange(*self.xlim,0.001)
    y = self.gauss_fct(x, *self.popt)
    if self.order==1:
      return x,y
    else:
      y1 = self.gauss_single(x, *self.popt[:3])
      y2 = self.gauss_single(x, *self.popt[3:])
      return x,y,y1,y2

class SkewedGaussianFit:
  """
  Fitting data distribution with skewed Gaussian profiles.
  """
  def __init__(self,data,bins,xlim,order=1,reference=[]):
    self.xlim = xlim
    self.order = order
    hist = numpy.histogram(data,bins,range=xlim)
    x = numpy.array([0.5 * (hist[1][i] + hist[1][i+1]) for i in range(len(hist[1])-1)])
    y = hist[0]
    skewness = -5
    params = [max(y)/3,numpy.mean(data),numpy.std(data),skewness]*order
    # popt = [2e4, 49.5, 0.2, 2e4, 50, 0.2, -5]
    self.reference = reference
    if len(reference)>0:
      self.reference = SkewedGaussianFit(reference,bins,xlim).get_params()
      params = params[4:]
    self.skew_fit(x,y,params)

  def skew_single(self, x, amp, mu, sigma, skewness):
    r"""A skewed Gaussian model, using a skewed normal distribution.
    The model has four Parameters: `amplitude` (:math:`A`), `center`
    (:math:`\mu`), `sigma` (:math:`\sigma`), and `gamma` (:math:`\gamma`).

    .. math::

        f(x; A, \mu, \sigma, \gamma) = \frac{A}{\sigma\sqrt{2\pi}}
        e^{[{-{(x-\mu)^2}/{{2\sigma}^2}}]} \Bigl\{ 1 +
        {\operatorname{erf}}\bigl[
        \frac{{\gamma}(x-\mu)}{\sigma\sqrt{2}}
        \bigr] \Bigr\}

    where :func:`erf` is the error function.
    For more information, see:
    https://en.wikipedia.org/wiki/Skew_normal_distribution
    """
    normpdf = (amp / (sigma * numpy.sqrt(2 * math.pi))) * numpy.exp(-(numpy.power((x - mu), 2) / (2 * numpy.power(sigma, 2))))
    normcdf = (1 + special.erf((skewness * ((x - mu) / sigma)) / (numpy.sqrt(2))))
    return normpdf * normcdf

  def skew_fct(self, x, *params):
    skew = 0
    for i in range(self.order):
      if i==0 and self.reference!=[]:
        amp, mu, sigma, skewness = self.reference
      else:
        idx = i if self.reference==[] else i-1
        amp, mu, sigma, skewness = params[idx*4:idx*4+4]
      skew += self.skew_single(x, amp, mu, sigma, skewness)
    return skew

  def skew_fit(self,x,y,params):
    popt, pcov = curve_fit(self.skew_fct,x,y,p0=params)
    perr = numpy.sqrt(numpy.diag(pcov))
    print('1/%i Gaussian (skewed) : amp=%i±%i, mu=%.3f±%.3f, sigma=%.3f±%.3f, skewness=%.2f±%.2f'%(self.order,popt[0],perr[0],popt[1],perr[1],popt[2],perr[2],popt[3],perr[3]))
    if self.order>1 and self.reference==[]:
      print('2/%i Gaussian (skewed) : amp=%i±%i, mu=%.3f±%.3f, sigma=%.3f±%.3f, skewness=%.2f±%.2f'%(self.order,popt[4],perr[4],popt[5],perr[5],popt[6],perr[6],popt[7],perr[7]))
    self.popt = self.reference+list(popt)

  def get_params(self):
    return self.popt

  def get_fit(self):
    self.reference = []
    x = numpy.arange(*self.xlim,0.001)
    y = self.skew_fct(x, *self.popt)
    if self.order==1:
      return x,y
    else:
      y1 = self.skew_single(x, *self.popt[:4])
      y2 = self.skew_single(x, *self.popt[4:])
      return x,y,y1,y2

class MixedGaussianFit:

  def __init__(self,data,bins,xlim,reference=[]):
    self.xlim = xlim
    hist = numpy.histogram(data,bins,range=xlim)
    x = numpy.array([0.5 * (hist[1][i] + hist[1][i+1]) for i in range(len(hist[1])-1)])
    y = hist[0]
    skewness = -5
    params = [max(y)/3,numpy.mean(data),numpy.std(data)]
    params+= [max(y)/3,numpy.mean(data),numpy.std(data),skewness]
    # popt = [2e4, 49.5, 0.2, 2e4, 50, 0.2, -5]
    self.reference = reference
    if len(reference)>0:
      self.reference = GaussianFit(reference,bins,xlim).get_params()
    self.mix_fit(x,y,params)

  def gauss_fct(self,x,*params):
    amp, mu, sigma = params[:3]
    if self.reference!=[]:
      amp, mu, sigma = self.reference
    return (amp * numpy.exp(-(x - mu)**2.0 / (2 * sigma**2)))

  def skew_fct(self, x, *params):
    amp, mu, sigma, gamma = params[3:]
    normpdf = (amp / (sigma * numpy.sqrt(2 * math.pi))) * numpy.exp(-(numpy.power((x - mu), 2) / (2 * numpy.power(sigma, 2))))
    normcdf = (1 + special.erf((gamma * ((x - mu) / sigma)) / (numpy.sqrt(2))))
    return normpdf * normcdf

  def mix_fct(self, x, *params):
    gauss = self.gauss_fct(x,*params)
    skew = self.skew_fct(x,*params)
    return gauss + skew

  def mix_fit(self,x,y,params):
    popt, pcov = curve_fit(self.mix_fct,x,y,p0=params)
    print('1/2 Gaussian : amp=%.2f, mu=%.2f, sigma=%.3f'%(popt[0],popt[1],abs(popt[2])))
    print('2/2 Gaussian (skewed) : amp=%.2f, mu=%.2f, sigma=%.3f, skewness=%3f'%(popt[3],popt[4],popt[5],popt[6]))
    self.popt = popt

  def get_fit(self):
    x = numpy.arange(*self.xlim,0.001)
    y = self.mix_fct(x, *self.popt)
    y1 = self.gauss_fct(x, *self.popt)
    y2 = self.skew_fct(x, *self.popt)
    return x,y,y1,y2

class IndSkewedGaussian:
  """
  Fitting independently day and night distributions using
  skewed Gaussian profiles.

  Examples
  --------
  >>> data = nuri.get_data('2016-3-14','2016-4-11','/content/drive/MyDrive/CityMagData/1Hz',station=2,sensor='biomed',scalar=True)
  >>> day, night = nuri.day_and_night(data.value,daytime=[[0,1],[4.5,24]])
  >>> x,y,y1,y2 = nuri.gaussian_fit(mode='indskew',data=data.value,bins=45,xlim=[48.8,50.3],order=2,reference=[day,night]).get_fit()
  1/1 Gaussian (skewed) : amp=67980.04, mu=49.36, sigma=0.281, skewness=1.393503
  1/1 Gaussian (skewed) : amp=11488.11, mu=49.92, sigma=0.212, skewness=-4.605114
  """
  def __init__(self,data,bins,xlim,order=1,reference=[]):
    self.xlim = xlim
    self.order = order
    hist = numpy.histogram(data,bins,range=xlim)
    x = numpy.array([0.5 * (hist[1][i] + hist[1][i+1]) for i in range(len(hist[1])-1)])
    y = hist[0]
    self.popt = []
    for ref in reference:
      self.popt.extend(SkewedGaussianFit(ref,bins,xlim).get_params())

  def skew_single(self, x, amp, mu, sigma, skewness):
    normpdf = (amp / (sigma * numpy.sqrt(2 * math.pi))) * numpy.exp(-(numpy.power((x - mu), 2) / (2 * numpy.power(sigma, 2))))
    normcdf = (1 + special.erf((skewness * ((x - mu) / sigma)) / (numpy.sqrt(2))))
    return normpdf * normcdf

  def skew_fct(self, x, *params):
    skew = 0
    for i in range(self.order):
      amp, mu, sigma, skewness = params[i*4:i*4+4]
      skew += self.skew_single(x, amp, mu, sigma, skewness)
    return skew

  def get_fit(self):
    x = numpy.arange(*self.xlim,0.001)
    y = self.skew_fct(x, *self.popt)
    if self.order==1:
      return x,y
    else:
      y1 = self.skew_single(x, *self.popt[:4])
      y2 = self.skew_single(x, *self.popt[4:])
      return x,y,y1,y2
    
def gaussian_fit(mode,data,bins,xlim,order=2,reference=[]):
  """
  
  """
  if mode=='gauss':
    return GaussianFit(data,bins,xlim,order,reference).get_fit()
  if mode=='skew':
    return SkewedGaussianFit(data,bins,xlim,order,reference).get_fit()
  if mode=='indskew':
    return IndSkewedGaussian(data,bins,xlim,order,reference).get_fit()
  if mode=='mixed':
    return MixedGaussianFit(data,bins,xlim,reference).get_fit()



#!/usr/bin/env python
import nuri,mlpy,numpy,os
from matplotlib.colors import LogNorm
import matplotlib.pyplot as plt
path = '/Users/vincent/Google\ Drive/research/UrbanMagnetometry/Processed\ Data/1Hz/'
data = nuri.get_data('2016-5-2','2016-6-6',path,station=4,sensor='biomed')
n,i,length = 1,600*28,3600
omega0 = 6
scales = mlpy.wavelet.autoscales(N=length,dt=1,dj=0.05,wf='morlet',p=omega0)
while i+1<len(data):
    spec = mlpy.wavelet.cwt(data.value[i:i+length],dt=1,scales=scales,wf='morlet',p=omega0)
    spec = numpy.abs(spec)**2
    freq = (omega0 + numpy.sqrt(2.0 + omega0 ** 2)) / (4 * numpy.pi * scales[1:])
    idx = abs(freq-1e-2).argmin()
    fig = plt.figure(figsize=(40,7),dpi=50)
    ax = fig.add_axes([0,0,1,1])
    ax.imshow(spec[:idx],extent=[0,length,freq[idx],freq[0]],aspect='auto',
               interpolation='nearest',cmap='jet',norm=LogNorm(0.000001,0.1))
    plt.grid(False)
    plt.savefig('image-%04i'%n)
    plt.close()
    n+=1
    i+=10
    if n==1001: break
os.system('ffmpeg -r 25 -f image2 -i image-%04d.png -vcodec libx264 -crf 25  -pix_fmt yuv420p wavelet.mp4')
os.system('rm image*')



import pathlib
import pkg_resources
from setuptools import setup,find_packages
from glob import glob
import nuri

with pathlib.Path('requirements.txt').open() as requirements_txt:
    install_requires = [
        str(requirement)
        for requirement
        in pkg_resources.parse_requirements(requirements_txt)
    ]

with open('README.md', 'r') as f:
    longdesc = f.read()

setup(
    name="nuri",
    version=nuri.__version__,
    description="Time-frequency and sensor network analysis software for urban magnetometry data.",
    long_description=longdesc,
    long_description_content_type='text/markdown',
    scripts = glob('bin/*'),
    author="Vincent Dumont",
    author_email="vincentdumont11@gmail.com",
    maintainer="Vincent Dumont",
    maintainer_email="vincentdumont11@gmail.com",
    url="http://citymag.gitlab.io/nuri/",
    license_files = ('LICENSE.txt',),
    packages=find_packages(include=('nuri*',)),
    project_urls={
        "Source Code": "https://gitlab.com/citymag/analysis/nuri",
    },
    install_requires=["astropy","gwpy","h5py","matplotlib","numpy"],
    classifiers=[
        'Intended Audience :: Science/Research',
        "License :: Other/Proprietary License",
        'Natural Language :: English',
        "Operating System :: OS Independent",
        'Programming Language :: Python',
        'Topic :: Scientific/Engineering :: Physics',
    ],

)
